%define rev 1785

%define rel 15

Name:           xaralx
License:        GPLv2
Group:          Graphics/Editors and Converters
Version:        0.7
Release:        %mkrel -c rev%{rev} %{rel}
Summary:        Xara Xtreme for Linux is a powerful, general purpose vector graphics program
URL:            http://www.xaraxtreme.org/

BuildRequires:  gcc-c++
BuildRequires:  pkgconfig(libjpeg)
BuildRequires:  pkgconfig(libtiff-4)
BuildRequires:  pkgconfig(libpng)
BuildRequires:  pkgconfig(libxml-2.0)
BuildRequires:  gettext-devel
BuildRequires:  wxgtku2.8-devel
#documentation has wrong file end of line encoding
BuildRequires:  dos2unix
BuildRequires:  zip
BuildRequires:  unzip

#https://downloads.xara.com/opensource/%{name}%{version}_rev%{rev}.tar.bz2
Source0:        XaraLX-%{version}r%{rev}.tar.bz2
#from OpenSuse
Source1:        XARFormatDocument.pdf
Source2:        %{name}.desktop
#from https://translations.launchpad.net/xaralx
Source3:        XaraLX-i18n-0.7r1785.tar.gz

Patch1:         abuild.diff
Patch2:         XaraLX-0.7r1785-missing-declaration.patch
Patch3:         xaralx-0.7_p1785-pragma-gentoo.patch
Patch4:         xaralx-gsocket.patch
Patch5:         xaralx-0.7_p1785-libpng15-gentoo.patch
Patch6:         30_gtk_wxwidgets_symbol_clash-deb.patch
Patch7:         50_update_imagemagick_version_parser-deb.patch
Patch8:         add-linker-flags-deb-mga.patch
Patch9:         wxOil-wxHandleFatalError.patch
Patch10:        xaralx-pragma.patch

Requires:       imagemagick
Provides:       XaraLX = %{version}

ExclusiveArch:	%{ix86} x86_64 ppc

%description
Xara Xtreme for Linux is a powerful, general purpose
vector graphics program for Unix platforms including
Linux, FreeBSD and (in development) OS-X. Formerly known
as Xara LX, it is based on Xara Xtreme for Windows,
which is the fastest graphics program available, period.
The Xara Xtreme source code was made available open-source
in early 2006, and is being ported to Linux. This process
is almost complete and Xara Xtreme for Linux is available
for download now.

%package devel
Summary:        Development files for XaraLX
Group:          Development/Other
License:        GPLv2
Requires:       %{name} = %{version}
Requires:       wxgtku2.8-devel
Requires:       jpeg-devel
Requires:       pkgconfig(libtiff-4)
Requires:       pkgconfig(libpng)

%description devel
Files to develop applications using XaraLX.

%prep
%setup -q -n XaraLX-%{version}r%{rev}
pushd po
tar -xf %{SOURCE3}
popd
%patch -P 1 -p1
%patch -P 2 -p1
%patch -P 3 -p1
%patch -P 4 -p1
%patch -P 5 -p1
%patch -P 6 -p1
%patch -P 7 -p1
%patch -P 8 -p1
%patch -P 9 -p0
%patch -P 10 -p0
find -type d -name .svn -print0 | xargs -0 rm -rf {} \;
#string "800_by_600_drawing.xar" must not be translated
sed -i 's|msgstr "800 на 600 drawing.xar"|msgstr ""|g' po/ru.po

%build
./autogen.sh

pushd filters/SVGFilter
autoreconf -f -i
popd

CXXFLAGS="%{optflags} -fno-strict-aliasing -fpermissive -std=gnu++03" \
CFLAGS="%{optflags} -fno-strict-aliasing" \
%configure --enable-unicode \
               --enable-xarlib \
               --enable-filters \
               --disable-svnversion

%make_build

# Compile locales by hand.
pushd po
    for f in *.po; do
        t=${f#%{name}-}
        msgfmt -v -o "${t%.po}.mo" "$f"
    done
popd

%install
%make_install

mkdir -p %{buildroot}%{_bindir}
(cd %{buildroot}%{_bindir} && ln -s XaraLX xara && ln -s XaraLX %{name})
(cd %{buildroot}%{_datadir} && ln -s %{name} XaraLX)

# /usr/share/%{name}/doc/%{name}/ is used by the application for online help
(cd %{buildroot}%{_datadir}/%{name} && ln -s %{_docdir}/%{name}/help doc)

install -D -m 644 doc/en/LICENSE %{buildroot}%{_docdir}/%{name}/help/LICENSE
install -m 644 %{SOURCE1} %{buildroot}%{_docdir}/%{name}

cp -a Designs TextDesigns Templates filters/SVGFilter/{tests,images,openclipart,samples} testfiles %{buildroot}%{_datadir}/%{name}
cat doc/en/%{name}Help.tar.gz | (cd %{buildroot}%{_docdir}/%{name}/help; tar zxvf - )

find %{buildroot}%{_docdir} -type f -print0 | xargs -0 dos2unix -q -o;
find %{buildroot}%{_datadir} %{buildroot}%{_docdir} -type f -print0 | xargs -0 chmod 644;

perl -ape 's{((src|document.location\s+)=.?")}{$1help/}g;' < %{buildroot}%{_docdir}/%{name}/help/%{name}.htm > %{buildroot}%{_docdir}/%{name}/help.html

install -m 644 COPYING LICENSE README MTRand.txt doc/gifutil.txt doc/XSVG.txt %{buildroot}%{_docdir}/%{name}/

install -D -m 644 doc/%{name}.1 %{buildroot}%{_mandir}/man1/%{name}.1
(cd %{buildroot}%{_mandir}/man1 && ln -s %{name}.1 XaraLX.1 && ln -s %{name}.1 xara.1)

install -D -m 644 %{name}.png %{buildroot}%{_datadir}/pixmaps/%{name}.png
install -D -m 644 %{SOURCE2} %{buildroot}%{_datadir}/applications/%{name}.desktop
chmod 755 %{buildroot}%{_datadir}/%{name}/tests/makerandom.sh

# Install locales by hand.
pushd po
    for f in *.mo; do
        install -pD -m644 "$f" "%{buildroot}%_datadir/locale/${f%.mo}/LC_MESSAGES/XaraLX.mo"
    done
popd
                
%find_lang XaraLX

%files -f XaraLX.lang
%doc %{_docdir}/%{name}
%{_bindir}/*
%{_datadir}/XaraLX
%dir %{_datadir}/%{name}
%{_datadir}/%{name}/*
%{_datadir}/applications/*.desktop
%{_datadir}/pixmaps/%{name}.png
%{_mandir}/man1/*

%files devel
%dir %{_includedir}/xarlib
%{_includedir}/xarlib/*.h
%{_libdir}/libXar.a
%{_libdir}/pkgconfig/Xar.pc


%changelog
* Mon Jul 07 2025 umeabot <umeabot> 0.7-0.rev1785.15.mga10
+ Revision: 2248378
- Mageia 10 Mass Rebuild

* Sun Mar 16 2025 wally <wally> 0.7-0.rev1785.14.mga10
+ Revision: 2165064
- rebuild for libxml2 2.13.6

* Sun Dec 22 2024 pterjan <pterjan> 0.7-0.rev1785.13.mga10
+ Revision: 2128304
- Rebuild for patchN deprecation

* Thu Nov 24 2022 ghibo <ghibo> 0.7-0.rev1785.12.mga9
+ Revision: 1910736
- Fix spec file to get package build (autobuild fail)
+ umeabot <umeabot>
- Mageia 9 Mass Rebuild

* Fri Feb 14 2020 umeabot <umeabot> 0.7-0.rev1785.10.mga8
+ Revision: 1518586
- Mageia 8 Mass Rebuild
+ wally <wally>
- replace deprecated %%configure2_5x

* Sun Sep 23 2018 umeabot <umeabot> 0.7-0.rev1785.9.mga7
+ Revision: 1301798
- Mageia 7 Mass Rebuild

* Sat Jun 03 2017 akien <akien> 0.7-0.rev1785.8.mga6
+ Revision: 1106136
- Rebuild for wxgtk 3.0.3.1

* Sat Jul 16 2016 pterjan <pterjan> 0.7-0.rev1785.7.mga6
+ Revision: 1042243
- Restrict to supported srchietctures

* Tue Feb 09 2016 umeabot <umeabot> 0.7-0.rev1785.6.mga6
+ Revision: 951569
- Mageia 6 Mass Rebuild

* Sun Jan 04 2015 alexl <alexl> 0.7-0.rev1785.5.mga5
+ Revision: 808363
- rewrote install section in spec
- fixed default template (template name must not be translated)

* Wed Oct 15 2014 umeabot <umeabot> 0.7-0.rev1785.4.mga5
+ Revision: 748161
- Second Mageia 5 Mass Rebuild

* Mon Sep 29 2014 umeabot <umeabot> 0.7-0.rev1785.3.mga5
+ Revision: 731531
- Mageia 5 Mass Rebuild

* Sun Aug 17 2014 alexl <alexl> 0.7-0.rev1785.2.mga5
+ Revision: 664710
- updated translations for application and for desktop file
- moved TryExec and Encoding from desktop file
- fixed unversioned provides
- fixed permissions for makerandom.sh

* Thu Apr 10 2014 alexl <alexl> 0.7-0.rev1785.1.mga5
+ Revision: 613164
- rewrite spec
- add new patches and move old patches
- add translations
+ matteo <matteo>
- improved patch relative to libpng15
- removing wrong br
- imported package xaralx

